==> flutter_application_id-0.0.5.tar.gz: test/plist_test.dart <==
import 'package:flutter_application_id/plist.dart';
import 'package:flutter_test/flutter_test.dart';

void main() {
  test('Should update value if present', () {
    final Plist plistUpdater = Plist.fromString('''
      <?xml version="1.0" encoding="UTF-8"?>
      <!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
      <plist version="1.0">
      <dict>
        <key>aKey</key>
        <string>valueBefore</string>
      </dict>
      </plist>
    ''');
    plistUpdater.updateString('aKey', 'valueAfter');
    expect(plistUpdater.toString(), '''
      <?xml version="1.0" encoding="UTF-8"?>
      <!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
      <plist version="1.0">
      <dict>
        <key>aKey</key>
        <string>valueAfter</string>
      </dict>
      </plist>
    ''');
  });

  test('Should not update value if absent', () {
    final Plist plistUpdater = Plist.fromString('''
      <?xml version="1.0" encoding="UTF-8"?>
      <!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
      <plist version="1.0">
      <dict>
        <key>aKey</key>
        <string>valueBefore</string>
      </dict>
      </plist>
    ''');
    plistUpdater.updateString('absentKey', 'valueAfter');
    expect(plistUpdater.toString(), '''
      <?xml version="1.0" encoding="UTF-8"?>
      <!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
      <plist version="1.0">
      <dict>
        <key>aKey</key>
        <string>valueBefore</string>
      </dict>
      </plist>
    ''');
  });
}

==> flutter_application_id-0.0.6.tar.gz: test/plist_test.dart <==
import 'package:flutter_application_id/file_updater/file_updater.dart';
import 'package:flutter_application_id/file_updater/rules/plist.dart';
import 'package:flutter_test/flutter_test.dart';

void main() {
  FileUpdater _fileUpdater;

  void givenFileContent(String fileContent) {
    _fileUpdater = FileUpdater.fromString(fileContent);
  }

  void whenUpdating(String key, String value) {
    _fileUpdater.update(Plist(key, value));
  }

  void thenExpectsFileContent(String fileContent) {
    expect(_fileUpdater.toString(), fileContent);
  }

  test('Should update value if present', () {
    givenFileContent('''
      <?xml version="1.0" encoding="UTF-8"?>
      <!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
      <plist version="1.0">
      <dict>
        <key>aKey</key>
        <string>valueBefore</string>
      </dict>
      </plist>
    ''');
    whenUpdating('aKey', 'valueAfter');
    thenExpectsFileContent('''
      <?xml version="1.0" encoding="UTF-8"?>
      <!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
      <plist version="1.0">
      <dict>
        <key>aKey</key>
        <string>valueAfter</string>
      </dict>
      </plist>
    ''');
  });

  test('Should not update value if absent', () {
    givenFileContent('''
      <?xml version="1.0" encoding="UTF-8"?>
      <!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
      <plist version="1.0">
      <dict>
        <key>aKey</key>
        <string>valueBefore</string>
      </dict>
      </plist>
    ''');
    whenUpdating('absentKey', 'valueAfter');
    thenExpectsFileContent('''
      <?xml version="1.0" encoding="UTF-8"?>
      <!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
      <plist version="1.0">
      <dict>
        <key>aKey</key>
        <string>valueBefore</string>
      </dict>
      </plist>
    ''');
  });
}
